BFGraph: KmerIterator Class Reference

BFGraph

Public Member Functions
KmerIterator Class Reference

Inherits iterator< std::input_iterator_tag, std::pair< Kmer, int >, int >.

## Public Member Functions
| KmerIterator (const char *s)
| KmerIterator (const KmerIterator &o)
KmerIterator & | operator++ ()
KmerIterator & | operator+= (const int length)
KmerIterator | operator++ (int)
void | raise (Kmer &km, Kmer &rep)
bool | operator== (const KmerIterator &o)
bool | operator!= (const KmerIterator &o)
std::pair< Kmer, int > & | operator* ()
std::pair< Kmer, int > * | operator-> ()

The documentation for this class was generated from the following files:

- src/KmerIterator.hpp
- src/KmerIterator.cpp